@@ -1,48 +1,16 @@
 (*
  * System calls.
- *
- * ----------------------------------------------------------------
- *
- * @begin[license]
- * Copyright (C) 2004-2006 Mojave Group, Caltech
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; version 2
- * of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * Additional permission is given to link this library with the
- * with the Objective Caml runtime, and to redistribute the
- * linked executables.  See the file LICENSE.OMake for more details.
- *
- * Author: Jason Hickey @email{jyh@cs.caltech.edu}
- * Modified By: Aleksey Nogin @email{nogin@cs.caltech.edu}
- * @end[license]
  *)
-open Lm_printf
-open Lm_debug
-
-open Omake_pos
-open Omake_exn_print
-open Omake_shell_type
-open Omake_shell_sys_type
-
 (*
  * These functions are directly exported.
  *)
-external ext_set_tty_pgrp   : pgrp -> unit                = "omake_shell_sys_set_tty_pgrp"
-external ext_setpgid        : pid -> pid -> unit          = "omake_shell_sys_setpgid"
+external ext_set_tty_pgrp : 
+  Omake_shell_sys_type.pgrp -> unit = "omake_shell_sys_set_tty_pgrp"
+external ext_setpgid : 
+  Omake_shell_sys_type.pid ->
+  Omake_shell_sys_type.pid -> unit = "omake_shell_sys_setpgid"
 
-let interact = ref (Omake_readline.isatty ())
+let interact = ref (Lm_readline.isatty ())
 
 let set_interactive flag =
    interact := flag
@@ -86,32 +54,30 @@ let do_close_on_fork () =
    FdSet.iter Unix.close !close_on_fork;
    close_on_fork := FdSet.empty
 
-(*
- * Send a signal to a process.
- *)
+(**  Send a signal to a process. *)
 let signo_of_signal = function
-   SigAbrt -> Sys.sigabrt
- | SigAlrm -> Sys.sigalrm
- | SigFPE  -> Sys.sigfpe
- | SigHup  -> Sys.sighup
- | SigIll  -> Sys.sigill
- | SigInt  -> Sys.sigint
- | SigKill -> Sys.sigkill
- | SigPipe -> Sys.sigpipe
- | SigQuit -> Sys.sigquit
- | SigSegv -> Sys.sigsegv
- | SigTerm -> Sys.sigterm
- | SigUsr1 -> Sys.sigusr1
- | SigUsr2 -> Sys.sigusr2
- | SigChld -> Sys.sigchld
- | SigCont -> Sys.sigcont
- | SigStop -> Sys.sigstop
- | SigTstp -> Sys.sigtstp
- | SigTtin -> Sys.sigttin
- | SigTtou -> Sys.sigttou
- | SigVTAlrm -> Sys.sigvtalrm
- | SigProf   -> Sys.sigprof
- | SigNum i  -> i
+  | Omake_shell_type.SigAbrt -> Sys.sigabrt
+  | SigAlrm -> Sys.sigalrm
+  | SigFPE  -> Sys.sigfpe
+  | SigHup  -> Sys.sighup
+  | SigIll  -> Sys.sigill
+  | SigInt  -> Sys.sigint
+  | SigKill -> Sys.sigkill
+  | SigPipe -> Sys.sigpipe
+  | SigQuit -> Sys.sigquit
+  | SigSegv -> Sys.sigsegv
+  | SigTerm -> Sys.sigterm
+  | SigUsr1 -> Sys.sigusr1
+  | SigUsr2 -> Sys.sigusr2
+  | SigChld -> Sys.sigchld
+  | SigCont -> Sys.sigcont
+  | SigStop -> Sys.sigstop
+  | SigTstp -> Sys.sigtstp
+  | SigTtin -> Sys.sigttin
+  | SigTtou -> Sys.sigttou
+  | SigVTAlrm -> Sys.sigvtalrm
+  | SigProf   -> Sys.sigprof
+  | SigNum i  -> i
 
 let kill pgrp signal =
    Unix.kill pgrp (signo_of_signal signal)
@@ -163,12 +129,31 @@ let dup stdin stdout stderr =
       Unix.close stdout';
       Unix.close stderr'
 
+let dup_actions workfd stdin stdout stderr =
+  (* Careful: dup2(fd1,fd2) also clears the close-on-exec flag for the
+     duplicate. However, dup2(fd,fd) is, according to POSIX, a no-op.
+     We work around by doing dup2(fd,workfd); dup2(workfd,fd) in sequence
+     (where workfd is an arbitrary other file descriptor)
+   *)
+  let open Omake_shell_spawn in
+  [ Fda_dup2(stdin, workfd);
+    Fda_dup2(workfd, Unix.stdin);
+    Fda_dup2(stdout, workfd);
+    Fda_dup2(workfd, Unix.stdout);
+    Fda_dup2(stderr, workfd);
+    Fda_dup2(workfd, Unix.stderr);
+    Fda_close(workfd);
+  ] @
+    ( if stdin <> Unix.stdin then [ Fda_close stdin ] else [] ) @
+      ( if stdout <> Unix.stdout then [ Fda_close stdout ] else [] ) @
+        ( if stderr <> Unix.stderr && stderr <> stdout then [ Fda_close stderr ] else [] )
+
 (*
  * Create a thread.
  * This actually creates a process on Unix.
  *)
 let create_thread info =
-   let { create_thread_stdin = stdin;
+   let { Omake_shell_sys_type.create_thread_stdin = stdin;
          create_thread_stdout = stdout;
          create_thread_stderr = stderr;
          create_thread_pgrp = pgrp;
@@ -177,6 +162,7 @@ let create_thread info =
        } = info
    in
    Pervasives.flush_all();
+   Lm_unix_util.moncontrol false;
    let pid = Unix.fork () in
       if pid = 0 then
          let code =
@@ -202,7 +188,7 @@ let create_thread info =
                   code
              | exn ->
                   let () =
-                     try eprintf "%a@." pp_print_exn exn with _ -> ()
+                     try Format.eprintf "%a@." Omake_exn_print.pp_print_exn exn with _ -> ()
                   in
                      Omake_state.exn_error_code
          in
@@ -214,44 +200,45 @@ let create_thread info =
  * Create a process.
  *)
 let create_process info =
-   let { create_process_stdin = stdin;
-         create_process_stdout = stdout;
-         create_process_stderr = stderr;
-         create_process_pgrp = pgrp;
-         create_process_dir = dir;
-         create_process_env = env;
-         create_process_exe = exe;
-         create_process_argv = argv;
-         create_process_background = bg
-       } = info
-   in
-(*
-      eprintf "@[<v 3>";
-      Array.iter (fun s ->
-            eprintf "@ %s" s) argv;
-      eprintf "@]@.";
- *)
-   let pid = Unix.fork () in
-      if pid = 0 then
-         try
-            let () =
-               if pgrp = 0 then
-                  let pid = Unix.getpid () in
-                     setpgid pid pid;
-                     if not bg then
-                        set_tty_pgrp pgrp;
-            in
-               dup stdin stdout stderr;
-               Unix.handle_unix_error Unix.chdir dir;
-               Unix.handle_unix_error (fun () -> Unix.execve exe argv env) ()
-         with _ ->
-            exit Omake_state.exn_error_code
-      else
-         pid
+  match info with 
+    {Omake_shell_sys_type.create_process_stdin = stdin;
+     create_process_stdout = stdout;
+     create_process_stderr = stderr;
+     create_process_pgrp = pgrp;
+     create_process_dir = dir;
+     create_process_env = env;
+     create_process_exe = exe;
+     create_process_argv = argv;
+     create_process_background = bg
+    }  -> 
 
 (*
- * -*-
- * Local Variables:
- * End:
- * -*-
+      Format.eprintf "@[<v 3>";
+      Array.iter (fun s ->
+            Format.eprintf "@ %s" s) argv;
+      Format.eprintf "@]@.";
  *)
+    Unix.handle_unix_error
+      (fun () ->
+         Lm_unix_util.moncontrol false;
+         let workfd = Unix.openfile "." [Unix.O_RDONLY] 0 in
+         let pid =
+           Omake_shell_spawn.spawn
+             ~chdir:(Omake_shell_spawn.Wd_chdir dir)
+             ~env
+             ~pg:( if !interact && pgrp = 0 then (
+                     if bg then
+                       Omake_shell_spawn.Pg_new_bg_group
+                     else
+                       Omake_shell_spawn.Pg_new_fg_group
+                   ) else
+                     Omake_shell_spawn.Pg_keep
+                 )
+             ~fd_actions:(dup_actions workfd stdin stdout stderr)
+             exe
+             argv in
+         Unix.close workfd;
+         Lm_unix_util.moncontrol true;
+         pid
+      )
+      ()
